CheckmarkTheme class

A Widget that controls how descendant Checkmarks should look like.

Inheritance

Constructors

CheckmarkTheme({Key? key, required CheckmarkThemeData data, required Widget child})
Creates a theme that controls how descendant Checkmarks should look like.
const

Properties

child → Widget
The widget below this widget in the tree.
finalinherited
data → CheckmarkThemeData
The properties for descendant Checkmarks
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant CheckmarkTheme oldWidget) → bool
Whether the framework should notify widgets that inherit from this widget.
override
wrap(BuildContext context, Widget child) → Widget
Return a copy of this inherited theme with the specified child.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

maybeOf(BuildContext context) → CheckmarkThemeData?
The data from the closest instance of this class that encloses the given context.
merge({Key? key, Curve? curve, Duration? duration, Color? color, double? weight, double? size, bool? autoSize, bool? rounded, bool? drawCross, bool? drawDash, CheckmarkThemeData? data, required Widget child}) → Widget
Creates an CheckmarkTheme that controls the style of descendant widgets, and merges in the current CheckmarkTheme, if any.
of(BuildContext context) → CheckmarkThemeData
The data from the closest instance of this class that encloses the given context.