AnimatedTransform class

A widget that allows to dynamically change the appearance of the child widget over time. It achieves this by combining the functionality of a transformation widget with animation capabilities.

Inheritance

Constructors

AnimatedTransform({Key? key, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.linear, Offset offset = Offset.zero, double scale = 1.0, double rotate = 0.0, bool flipX = false, bool flipY = false, AlignmentGeometry? alignment = Alignment.center, required Widget child})
Create an animated transform widget
const

Properties

alignment → AlignmentGeometry?
The alignment of the origin, relative to the size of the child, if transform is specified.
final
child → Widget
The widget below this widget in the tree.
final
curve → Curve
The curve to apply when animating the parameters of this container.
finalinherited
duration → Duration
The duration over which to animate the parameters of this container.
finalinherited
flipX → bool
Controls whether the child widget is flipped horizontally (mirrored). Setting flipX to true will cause the child to be displayed as if reflected across a vertical axis.
final
flipY → bool
Controls whether the child widget is flipped vertically (inverted). Setting flipY to true will cause the child to be displayed as if reflected across a horizontal axis.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset → Offset
Moves a child element a certain distance away from its default position.
final
onEnd → VoidCallback?
Called every time an animation completes.
finalinherited
rotate → double
Rotates child element by a specified number of degrees. Use a positive value for clockwise rotation or a negative value for counter-clockwise rotation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Adjust the size of the child element relative to its original size. A value of 1 maintains the original size, while values greater than 1 enlarge and values less than 1 shrink the element.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → AnimatedTransformState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited