AnimatedBoxState class

Inheritance

Constructors

AnimatedBoxState()

Properties

alignmentTween ↔ AlignmentGeometryTween?
getter/setter pair
animation → Animation<double>
The animation driving this widget's implicit animations.
no setterinherited
borderShape → ShapeBorder
no setter
borderShapeTween ↔ ShapeBorderTween?
getter/setter pair
constraintsTween ↔ BoxConstraintsTween?
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller → AnimationController
The animation controller driving this widget's implicit animations.
latefinalinherited
decoration → Decoration
no setter
decorationTween ↔ DecorationTween?
getter/setter pair
elevationColorTween ↔ ColorTween?
getter/setter pair
elevationTween ↔ Tween<double?>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heightTween ↔ Tween<double?>?
getter/setter pair
marginTween ↔ EdgeInsetsGeometryTween?
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
paddingTween ↔ EdgeInsetsGeometryTween?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → WxAnimatedBox
The current configuration.
no setterinherited
widthTween ↔ Tween<double?>?
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateTweens() → void
Optional hook for subclasses that runs after all tweens have been updated via forEachTween.
inherited
didUpdateWidget(covariant WxAnimatedBox oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
forEachTween(TweenVisitor visitor) → void
Visits each tween controlled by this state with the specified visitor function.
override
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited