filledStyle method

Defines the style for the filled variant of the sheet. Can be overridden by subclasses to customize the filled style.

Implementation

WxSheetStyle filledStyle(WxSheetStyleResolverData data) {
  return const WxSheetStyle();
}