tonalStyle method

Defines the style for the tonal variant of the sheet. Can be overridden by subclasses to customize the tonal style.

Implementation

@override
tonalStyle(data) {
  return super.tonalStyle(data).copyWith(
        foregroundColor: colorScheme.onSurface,
        backgroundColor: appTheme.unselectedWidgetColor,
        selectedStyle: WxSheetStyle(
          foregroundColor: data.severity ?? primaryColor,
          backgroundColor: data.severity ?? primaryColor,
        ),
      );
}