WxTapSheetThemeData class

Inheritance
Implementers

Constructors

WxTapSheetThemeData({bool? animated, Curve? curve, Duration? duration, WxSheetVariant? variant, WxSheetSize? size, Color? severity, WxSheetStyle style = const WxSheetStyle(), WxSheetStyleResolver<WxSheetStyle>? styleResolver, bool? overlay, bool? feedback, bool? focusable, bool? disabled, bool? inherits, MouseCursor? mouseCursor, Widget? leading, Widget? trailing})
Creates a theme data that can be used for SheetTheme.
const
WxTapSheetThemeData.from([WxSheetThemeData<WxTapSheetThemeData>? other, WxSheetThemeData<WxTapSheetThemeData> fallback = const WxTapSheetThemeData()])

Properties

animated bool?
Whether to animate the sheet decoration.
finalinherited
curve Curve?
The curve to apply when animating the parameters of sheet widget.
finalinherited
disabled bool?
Whether the descent WxAnchor is disabled for interaction.
finalinherited
duration Duration?
The duration over which to animate the parameters of sheet widget.
finalinherited
effectiveStyle WxSheetStyle
Retrieves the effective style based on the provided properties.
no setterinherited
feedback bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
finalinherited
focusable bool?
If true, this widget may request the primary focus.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
inherits bool?
Whether the sheet inherits variant, severity, and size from its parent theme.
finalinherited
leading Widget?
A custom widget to display prior to the sheet's child.
finalinherited
mouseCursor MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
finalinherited
overlay bool?
Whether the overlay is enabled or not
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity Color?
Type of the sheet severity
finalinherited
size WxSheetSize?
Type of the sheet size
finalinherited
style WxSheetStyle
The WxSheetStyle to be applied to the sheet widget
finalinherited
styleResolver WxSheetStyleResolver<WxSheetStyle>?
Defines a function used to resolve the sheet style based on the variant and severity.
finalinherited
trailing Widget?
A custom widget to display next to the sheet's child.
finalinherited
type Object
The extension's type.
no setterinherited
variant WxSheetVariant?
Type of the sheet variant
finalinherited

Methods

copyWith({bool? animated, Curve? curve, Duration? duration, WxSheetVariant? variant, WxSheetSize? size, Color? severity, WxSheetStyle? style, WxSheetStyleResolver<WxSheetStyle>? styleResolver, bool? overlay, bool? feedback, bool? focusable, bool? disabled, bool? inherits, MouseCursor? mouseCursor, Widget? leading, Widget? trailing}) WxTapSheetThemeData
Creates a copy of this WxSheetThemeData but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant WxSheetThemeData<WxTapSheetThemeData>? other, double t) WxSheetThemeData<WxTapSheetThemeData>
Linearly interpolate with another ThemeExtension object.
inherited
merge(WxSheetThemeData<WxTapSheetThemeData>? other) WxTapSheetThemeData
Creates a copy of this WxSheetThemeData but with the given fields replaced with the new values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(WxSheetStyleResolverData data) WxSheetStyle
Return WxSheetStyle that depends on variant and severity
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited